@@ -15,7 +15,7 @@ use LWP::Protocol ();
 use Scalar::Util qw(blessed);
 use Try::Tiny qw(try catch);
 
-our $VERSION = '6.37';
+our $VERSION = '6.38';
 
 sub new
 {
@@ -1141,7 +1141,7 @@ LWP::UserAgent - Web user agent class
  $ua->timeout(10);
  $ua->env_proxy;
 
- my $response = $ua->get('http://search.cpan.org/');
+ my $response = $ua->get('http://example.com');
 
  if ($response->is_success) {
      print $response->decoded_content;  # or whatever
